@@ -106,7 +106,7 @@ extern int copy_xattr (const char *from, const char *to);
 
 #ifdef WITH_SELINUX
 extern int selinux_check_access (const char *__chuser,
-				 unsigned int __access);
+				 unsigned int __selaccess);
 extern int set_default_context (const char *filename,
 				char **prev_context);
 extern int restore_default_context (char *prev_context);
