@@ -40,7 +40,7 @@
 #endif
 
 int
-selinux_check_access (const char *chuser, unsigned int access)
+selinux_check_access (const char *chuser, unsigned int selaccess)
 {
   int status = -1;
   security_context_t user_context;
@@ -58,11 +58,11 @@ selinux_check_access (const char *chuser, unsigned int access)
 	  int retval = security_compute_av (user_context,
 					    user_context,
 					    SECCLASS_PASSWD,
-					    access,
+					    selaccess,
 					    &avd);
 
 	  if ((retval == 0) &&
-	      ((access & avd.allowed) == access))
+	      ((selaccess & avd.allowed) == selaccess))
 	    status = 0;
 	}
       context_free (c);
