@@ -38,22 +38,8 @@
 #define _(String) gettext (String)
 #endif
 
-#define DAY (24L*3600L)
 #define SCALE DAY
 
-/* Print the version information.  */
-static void
-print_version (const char *program)
-{
-  fprintf (stdout, "%s (%s) %s\n", program, PACKAGE, VERSION);
-  fprintf (stdout, gettext ("\
-Copyright (C) %s Thorsten Kukuk.\n\
-This is free software; see the source for copying conditions.  There is NO\n\
-warranty; not even for MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.\n\
-"), "2002, 2003");
-  /* fprintf (stdout, _("Written by %s.\n"), "Thorsten Kukuk"); */
-}
-
 static void
 print_usage (FILE *stream, const char *program)
 {
@@ -74,14 +60,6 @@ print_help (const char *program)
   fputs (_("  -v, --version  Print program version\n"), stdout);
 }
 
-static void
-print_error (const char *program)
-{
-  fprintf (stderr,
-           _("Try `%s --help' or `%s --usage' for more information.\n"),
-           program, program);
-}
-
 static int
 c2n (char c)
 {
@@ -253,7 +231,7 @@ main (int argc, char *argv[])
           print_help (program);
           return 0;
         case 'v':
-          print_version (program);
+          print_version (program, "2003");
           return 0;
         case 'u':
           print_usage (stdout, program);
