@@ -1,4 +1,4 @@
-/* Copyright (C) 2002, 2003 Thorsten Kukuk
+/* Copyright (C) 2002, 2003, 2004 Thorsten Kukuk
    Author: Thorsten Kukuk <kukuk@suse.de>
 
    This program is free software; you can redistribute it and/or modify
@@ -53,6 +53,7 @@
 #include <security/pam_misc.h>
 
 #include "dbg_log.h"
+#include "use_slp.h"
 #include "logindefs.h"
 #include "error_codes.h"
 #include "rpasswd-client.h"
@@ -74,6 +75,10 @@ extern int setresuid(uid_t ruid, uid_t euid, uid_t suid);
 static SSL_CTX *ctx;
 /* Socket for incoming connections.  */
 static int sock4 = -1, sock6 = -1;
+#ifdef USE_SLP
+/* register/deregister at SLP server.  */
+static int use_slp = 0;
+#endif
 
 /* Print the version information.  */
 static void
@@ -84,15 +89,20 @@ print_version (const char *program)
 Copyright (C) %s Thorsten Kukuk.\n\
 This is free software; see the source for copying conditions.  There is NO\n\
 warranty; not even for MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.\n\
-"), "2002, 2003");
+"), "2004");
   /* fprintf (stdout, _("Written by %s.\n"), "Thorsten Kukuk"); */
 }
 
 static void
 print_usage (FILE *stream, const char *program)
 {
+#ifdef USE_SLP
+  fprintf (stream, _("Usage: %s [-4] [-6] [-d] [-c certificate] [-k privatekey] [-p port] [--slp]\n"),
+	   program);
+#else
   fprintf (stream, _("Usage: %s [-4] [-6] [-d] [-c certificate] [-k privatekey] [-p port]\n"),
 	   program);
+#endif
 }
 
 static void
@@ -109,6 +119,9 @@ print_help (const char *program)
   fputs (_("  -d             Run in debug mode\n"), stdout);
   fputs (_("  -p port        Port on which the server should listen\n"),
 	 stdout);
+#ifdef USE_SLP
+  fputs (_("  --slp          Register at local SLP server\n"), stdout);
+#endif
   fputs (_("  --help         Give this help list\n"), stdout);
   fputs (_("  --usage        Give a short usage message\n"), stdout);
   fputs (_("  --version      Print program version\n"), stdout);
@@ -950,6 +963,12 @@ termination_handler (int sig __attribute__ ((unused)))
 {
   close_sockets ();
 
+#ifdef USE_SLP
+  /* Remove from local SLP server.  */
+  if (use_slp)
+    deregister_slp ();
+#endif
+
   /* Clean up pid file.  */
   unlink (_PATH_RPASSWDDPID);
 
@@ -1019,6 +1038,7 @@ main (int argc, char **argv)
 	  {"ipv6",     no_argument,       NULL, '6'},
 	  {"certificate", required_argument, NULL, 'c'},
 	  {"privatekey",  required_argument, NULL, 'k'},
+	  {"slp",      no_argument,       NULL, '\252'},
           {"version",  no_argument,       NULL, '\255'},
           {"usage",    no_argument,       NULL, '\254'},
           {"help",     no_argument,       NULL, '\253'},
@@ -1050,6 +1070,11 @@ main (int argc, char **argv)
 	case 'p':
 	  port = htons (atol (optarg));
 	  break;
+#ifdef USE_SLP
+	case '\252':
+	  use_slp = 1;
+	  break;
+#endif
         case '\253':
           print_help (program);
           return 0;
@@ -1173,7 +1198,13 @@ main (int argc, char **argv)
   /* Init databases.  */
   server_init (port, ipv4, ipv6);
 
-  /* Handle incoming requests */
+#ifdef USE_SLP
+  /* Register at local SLP server.  */
+  if (use_slp)
+    register_slp (ntohs(port));
+#endif
+
+  /* Handle incoming requests.  */
   server_run ();
 
   return E_SUCCESS;
