@@ -1,4 +1,4 @@
-/* Copyright (C) 2003 Thorsten Kukuk
+/* Copyright (C) 2003, 2004 Thorsten Kukuk
    Author: Thorsten Kukuk <kukuk@suse.de>
 
    This program is free software; you can redistribute it and/or modify
@@ -500,7 +500,7 @@ write_defaults (const char *configfile, struct default_t *data)
     }
   fchmod (new_fd, oldmode.st_mode);
   fchown (new_fd, oldmode.st_uid, oldmode.st_gid);
-  if (copy_xattr (configfile, tmpname) > 0)
+  if (copy_xattr (configfile, tmpname) != 0)
     {
       fclose (fp);
       close (new_fd);
@@ -1216,7 +1216,7 @@ main (int argc, char **argv)
 	  print_help (program);
 	  return 0;
 	case 'v':
-	  print_version (program, "2003");
+	  print_version (program, "2004");
 	  return 0;
 	case '\254':
 	  print_usage (stdout, program);
@@ -1403,7 +1403,6 @@ main (int argc, char **argv)
       char *cp;
       unsigned int i;
       int retval = E_SUCCESS;
-      int asked_for_binddn = 0;
 
       memset (&pw_data, 0, sizeof (pw_data));
 
@@ -1557,7 +1556,7 @@ main (int argc, char **argv)
 #ifdef USE_LDAP
 	      if (gr_data->service == S_LDAP)
 		{
-		  if (binddn == NULL && !asked_for_binddn)
+		  if (binddn == NULL)
 		    {
 		      binddn = get_caller_dn ();
 		      if (binddn == NULL)
